#include "mex.h"
#include "algorithm"

using std::max;
using std::min;

void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
    // input 1: map, input 2: scale
    if (nrhs != 2)
        mexErrMsgTxt("2 inputs required!");
    double *x = mxGetPr(prhs[0]);
    int m = static_cast<int>(mxGetM(prhs[0]));
    int n = static_cast<int>(mxGetN(prhs[0]));
    int numel = m * n;
    int range = static_cast<int>(mxGetScalar(prhs[1]));
    
    // output: path
    int tempSize[] = {1, n};
    plhs[0] = mxCreateNumericArray(2, tempSize, mxINT32_CLASS, mxREAL);
    int *maxPre = reinterpret_cast<int*>(mxGetPr(plhs[0]));
    
    double *bestVal = new double[numel];
    int *bestPre = new int[numel];
    
    for (int j = 0; j < n; j++)
    {
        bestVal[j] = map[j];
    }
    
    for (int i = 1; i < n; i++)
    {
        for (int j = 0; j < m; j++)
        {
            int curSub = i * m + j;
            int lastRow = (i - 1) * m;
            bestVal[curSub] = bestVal[lastRow + j];
            bestPre[curSub] = j;
            
            int l = max(0, j - range);
            int r = min(m - 1, j + range);
            for (int k = j - 1; k >= l; k--)
            {
                int lastSub = lastRow + k;
                if (bestVal[curSub] < bestVal[lastSub])
                {
                    bestVal[curSub] = bestVal[lastSub];
                    bestPre[curSub] = k;
                }
            }
            for (int k = j + 1; k <= r; k++)
            {
                int lastSub = lastRow + k;
                if (bestVal[curSub] < bestVal[lastSub])
                {
                    bestVal[curSub] = bestVal[lastSub];
                    bestPre[curSub] = k;
                }
            }
            bestVal[curSub] += map[curSub];
        }
    }
    
    int curRow = (n - 1) * m;
    double maxVal = bestVal[curRow];
    maxPre[n - 1] = 0;
    for (int j = 1; j < m; j++)
    {
        if (maxVal < bestVal[curRow + j])
        {
            maxVal = bestVal[curRow + j];
            maxPre[n - 1] = j;
        }
        
    }
    for (int i = n - 2; i >= 0; i--)
    {
        maxPre[i] = bestPre[(i + 1) * m + maxPre[i + 1]];
    }
    for (int i = 0; i < n; i++)
    {
        maxPre[i] += 1;
    }
    
    delete bestVal;
    delete bestPre;
    return;
}