#include "mex.h"
#include "algorithm"
#include "memory"

using std::max;
using std::min;


void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
    // input 1: map, input 2: scale
    if (nrhs != 1)
        mexErrMsgTxt("1 inputs required!");
    double *X = mxGetPr(prhs[0]);
    int m = static_cast<int>(mxGetM(prhs[0]));
    int n = static_cast<int>(mxGetN(prhs[0]));
    if (n != 1)
        mexErrMsgTxt("input should of 1 column!");
    
    // output: path
    int tempSize[] = {1, m};
    plhs[0] = mxCreateNumericArray(2, tempSize, mxINT32_CLASS, mxREAL);
    int *res = reinterpret_cast<int*>(mxGetPr(plhs[0]));
    
    int id = 0;
    int mx = 0;
    
    res[0] = 0;
    for (int i = 1; i < m - 1; i++)
    {
        if (i < mx)
            res[i] = min(mx - i, res[2 * id - i]);
        while (X[i + res[i] + 1] == X[i - res[i] - 1]) 
            res[i] += 1; 
        if(i + res[i] > mx)
        {
            mx = i + res[i];
            id = i;
        }
    }
    
    bool *mask = new bool[m];
    memset(mask, 1, m * sizeof(bool));
    int rightBound = 0;
    for (int i = 0; i < m; i++)
        if (i + res[i] <= rightBound)
            mask[i] = 0;
        else
            rightBound = i + res[i];
    
    int leftBound = m + 1;
    for (int i = m - 1; i >= 0; i--)
        if (i - res[i] >= leftBound)
            mask[i] = 0;
        else
            leftBound = i - res[i];
    
    for (int i = 0; i < m; i++)
    {
        if (mask[i] == 0)
            res[i] = 0;
    }
    
    delete mask;
    
}