function [ x1, y1, x2, y2, score] = symmetricAxes(rgbImg, num, th)
%symmetricAxes Detect multiple axes
%   num: number of axes

x1 = zeros(num, 1);
x2 = zeros(num, 1);
y1 = zeros(num, 1);
y2 = zeros(num, 1);

rgbImg = imfilter(rgbImg, fspecial('gaussian', [5 5], 2), 'same');

xyzImg = rgb2xyz(rgbImg);
hsvImg = rgb2hsv(rgbImg);

%% set RANSAC options
options.epsilon = 1e-4;
options.P_inlier = 0.75;
options.sigma = 2;
options.est_fun = @estimate_line;
options.man_fun = @error_line;
%options.mode = 'MLESAC';
options.mode = 'RANSAC';
options.Ps = [];
options.notify_iter = [];
options.min_iters = 50;
options.fix_seed = false;
options.reestimate = true;
options.stabilize = false;

%% adjust image for palindrome detection

% parameters
imgSize = size(rgbImg);
Mfactor = 2;
Nfactor = 2;
imgSizeM = floor(imgSize(1) / Mfactor);
imgSizeN = floor(imgSize(2) / Nfactor);
alphaSize = 3;

%% palindrome detection

Q1 = mix(hsvImg(:,:,2), imgSizeM,imgSizeN);
Q1 = Q1(:);
Q1 = timeseries2symbol(Q1, length(Q1), length(Q1), alphaSize);
if numel(Q1) ~= imgSizeM * imgSizeN
    Q1 = zeros(imgSizeM, imgSizeN);
else
    Q1 = reshape(Q1, imgSizeM,imgSizeN);
end

%Q2 = mix(xyzImg(:,:,2), imgSizeM,imgSizeN);
Q2 = mix(double(rgb2gray(rgbImg)), imgSizeM,imgSizeN);
Q2 = Q2(:);
Q2 = timeseries2symbol(Q2, length(Q2), length(Q2), alphaSize);
Q2 = reshape(Q2, imgSizeM,imgSizeN);


Q3 = mix(xyzImg(:,:,2), imgSizeM,imgSizeN);
Q3 = Q3(:);
Q3 = timeseries2symbol(Q3, length(Q3), length(Q3), alphaSize);
Q3 = reshape(Q3, imgSizeM,imgSizeN);


map = zeros(imgSizeM,2*imgSizeN-1);
for ii = 1:imgSizeM
    %map(ii,:) = densePalindrome(Q(ii,:));
    %map(ii,:) = denseSelectedPalindrome(Q1(ii,:)) + .5 * denseSelectedPalindrome(Q2(ii,:)) + 1.5 * denseSelectedPalindrome(Q3(ii,:));
    map(ii,:) = 1 * palindrome(Q1(ii,:)) + 0.5 * palindrome(Q2(ii,:)) + 1.5 * palindrome(Q3(ii,:));   
    %map(ii,:) = palindrome(Q1(ii,:)) + 2 * palindrome(Q2(ii,:));
    %map(ii,:) = denseSelectedPalindrome(Q2(ii,:));
end

mask1 = (-cos(2 * pi * (1:2*imgSizeN-1)/ (2*imgSizeN)) + 1)/2;
map = map .* repmat(mask1, imgSizeM, 1);


%% axis detection
for nn = 1:num
    searchRange = floor(imgSize(1) / 201);
    X = double(findPath(map, searchRange));
    Y = 2:2:imgSizeM*2;

    for ii = 1:length(X)
        map(ii, X(ii)) = -inf;
    end
    
    X = X(imgSizeM/10:end-imgSizeM/10);
    Y = Y(imgSizeM/10:end-imgSizeM/10);
    ransacRes = RANSAC([X; Y], options);

    [l, r, score] = minLengthSubarray(ransacRes.CS, sum(ransacRes.CS)*th);
    if score > 0
        CS = ransacRes.CS;
        CS(1:l-1) = 0;
        CS(r+1:end) = 0;
        XCS = X(CS);
        YCS = Y(CS);
        slope = XCS / [YCS; ones(1, length(YCS))];
        y1(nn) = Y(l);
        y2(nn) = Y(r);
        x1(nn) = slope * [Y(l); 1];
        x2(nn) = slope * [Y(r); 1];
    end
end

